@@ -13,32 +13,29 @@
 #include "types.h"
 #include "gvplugin.h"
 #include "gvcjob.h"
+#include <stdbool.h>
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 #ifdef GVDLL
-#  define GVPLUGIN_LOADIMAGE_API __declspec(dllexport)
-#endif
-
-/*visual studio*/
-#ifdef _WIN32
-#ifndef GVC_EXPORTS
-#undef GVPLUGIN_LOADIMAGE_API
+#ifdef GVC_EXPORTS
+#define GVPLUGIN_LOADIMAGE_API __declspec(dllexport)
+#else
 #define GVPLUGIN_LOADIMAGE_API __declspec(dllimport)
 #endif
 #endif
-/*end visual studio*/
+
 #ifndef GVPLUGIN_LOADIMAGE_API
-#define GVPLUGIN_LOADIMAGE_API extern
+#define GVPLUGIN_LOADIMAGE_API /* nothing */
 #endif
 
-GVPLUGIN_LOADIMAGE_API boolean gvusershape_file_access(usershape_t *us);
+GVPLUGIN_LOADIMAGE_API bool gvusershape_file_access(usershape_t *us);
 GVPLUGIN_LOADIMAGE_API void gvusershape_file_release(usershape_t *us);
 
     struct gvloadimage_engine_s {
-	void (*loadimage) (GVJ_t *job, usershape_t *us, boxf b, boolean filled);
+	void (*loadimage) (GVJ_t *job, usershape_t *us, boxf b, bool filled);
     };
 
 #undef GVPLUGIN_LOADIMAGE_API
